@@ -25,7 +25,7 @@ class Lib:
     -------
     
     >>> from lyncs_cppyy import Lib
-    >>> zlib = Lib(header='zlib.h', library='libz', check='zlibVersion') 
+    >>> zlib = Lib(header='zlib.h', library='libz') 
     >>> zlib.zlibVersion()
      '1.2.11'
     
@@ -40,6 +40,7 @@ class Lib:
 
     __slots__ = [
         "_cwd",
+        "_loaded",
         "path",
         "include",
         "header",
@@ -50,6 +51,15 @@ class Lib:
         "redefined",
     ]
 
+    @staticmethod
+    def parse_arg(arg, name, types=str):
+        arg = () if arg is None else (arg,) if isinstance(arg, types) else tuple(arg)
+        if not all((isinstance(_, types) for _ in arg)):
+            raise TypeError(
+                f"Expected {types} for {name} but got {list(type(_) for _ in arg)}"
+            )
+        return arg
+
     def __init__(
         self,
         header=None,
@@ -85,50 +95,56 @@ class Lib:
         redefined: dict
           List of symbols that have been redefined
         """
-        assert check, "No checks given."
-        assert header, "No header given."
-        self._cwd = os.getcwd()
-        self.path = [path] if isinstance(path, str) else path
-        self.header = [header] if isinstance(header, str) else header
-        self.library = [library] if isinstance(library, str) else library or []
-        self.check = [check] if isinstance(check, str) else check
-        self.include = [include] if isinstance(include, str) else include or []
-        self.c_include = c_include
-        self.namespace = [namespace] if isinstance(namespace, str) else namespace or []
-        self.redefined = redefined or {}
 
-        if self.redefined:
-            self.check = [self.redefined.get(check, check) for check in self.check]
+        self._cwd = os.getcwd()
+        self._loaded = False
+        self.path = self.parse_arg(path, "path")
+        self.header = self.parse_arg(header, "header")
+        self.library = self.parse_arg(library, "library", (str, Lib))
+        self.check = self.parse_arg(check, "check")
+        self.include = self.parse_arg(include, "include")
+        self.c_include = c_include
+        self.namespace = self.parse_arg(namespace, "namespace")
+        self.redefined = dict(redefined or ())
 
     @property
-    def lib(self):
-        """
-        It checks if the library is already loaded, or it loads it.
-        """
-        if all((hasattr(cppyy.gbl, check) for check in self.check)):
-            return cppyy.gbl
+    def loaded(self):
+        "Returns if the library has been loaded"
+        return self._loaded
+
+    def load(self):
+        "Loads the library"
+        if self.loaded:
+            raise RuntimeError("Library already loaded")
 
         for include in self.include:
             cppyy.add_include_path(include)
 
         for library in self.library:
-            if isinstance(library, Lib):
-                library.lib
+            if isinstance(library, Lib) and not library.loaded:
+                library.load()
 
+        # Including headers
         self.define()
+
         for header in self.header:
+
+            # Searching for headers in paths
             for path in self.path:
                 if not path.startswith(os.sep):
                     path = self._cwd + "/" + path
                 if os.path.isfile(path + "/include/" + header):
                     cppyy.add_include_path(path + "/include")
                     break
+
             if self.c_include:
                 cppyy.c_include(header)
             else:
                 cppyy.include(header)
+
         self.undef()
 
+        # Loading libraries
         for library in self.library:
             if not isinstance(library, str):
                 continue
@@ -153,10 +169,13 @@ class Lib:
                 )
             cppyy.load_library(tmp)
 
-        assert all(
-            (hasattr(cppyy.gbl, check) for check in self.check)
-        ), "Given checks not found."
-        return self.lib
+        self._loaded = True
+
+        failed_checks = [_ for _ in self.check if not hasattr(self, _)]
+        if failed_checks:
+            raise RuntimeError(
+                f"The following checks have not been found: {failed_checks}"
+            )
 
     def define(self):
         "Defines the list of values in redefined"
@@ -175,20 +194,23 @@ class Lib:
             cppyy.cppdef(cpp)
 
     def __getattr__(self, key):
+        if not self.loaded:
+            self.load()
+
         try:
             if self.redefined:
                 key = self.redefined.get(key, key)
             if self.namespace:
                 for namespace in self.namespace:
                     try:
-                        return getattr(getattr(self.lib, namespace), key)
+                        return getattr(getattr(cppyy.gbl, namespace), key)
                     except AttributeError:
                         pass
-            return getattr(self.lib, key)
+            return getattr(cppyy.gbl, key)
         except AttributeError:
             try:
                 return self.get_macro(key)
-            except BaseException:
+            except ValueError:
                 pass
             raise
 
@@ -203,17 +225,18 @@ class Lib:
         if self.namespace:
             for namespace in self.namespace:
                 try:
-                    getattr(getattr(self.lib, namespace), key)
-                    return setattr(getattr(self.lib, namespace), key, value)
+                    getattr(getattr(cppyy.gbl, namespace), key)
+                    return setattr(getattr(cppyy.gbl, namespace), key, value)
                 except AttributeError:
                     pass
-        setattr(self.lib, key, value)
+        getattr(cppyy.gbl, key)
+        setattr(cppyy.gbl, key, value)
 
     def get_macro(self, key):
         "Returns the value of a defined macro by assigning it to a variable"
         try:
-            return getattr(self.lib, "_" + key)
-        except AttributeError as err:
+            return getattr(cppyy.gbl, "_" + key)
+        except AttributeError:
             try:
                 cppyy.cppdef(
                     """
@@ -223,4 +246,4 @@ class Lib:
                 )
                 return self.get_macro(key)
             except SyntaxError:
-                raise err
+                raise ValueError(f"{key} not found")
